class TuningCrowd:
    def __init__(self, n=30, mode="RLHF"):
        self.n = n
        self.mode = mode

    def feed(r):
        raise NotImplementedError("Please contact Bountyful team for beta access.")